pub struct ModuleHealthEvent {
pub ts_ns: u64,
pub seq: u64,
pub module_key: String,
pub previous_health: u32,
pub current_health: u32,
pub reason_code: String,
pub detail: String,
pub source: String,
}Fields
ts_ns: u64seq: u64module_key: Stringprevious_health: u32current_health: u32reason_code: Stringdetail: Stringsource: StringTrait Implementations
Sourceimpl Clone for ModuleHealthEvent
impl Clone for ModuleHealthEvent
Sourcefn clone(&self) -> ModuleHealthEvent
fn clone(&self) -> ModuleHealthEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleHealthEvent
impl Debug for ModuleHealthEvent
Sourceimpl Default for ModuleHealthEvent
impl Default for ModuleHealthEvent
Sourceimpl Hash for ModuleHealthEvent
impl Hash for ModuleHealthEvent
Sourceimpl Message for ModuleHealthEvent
impl Message for ModuleHealthEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ModuleHealthEvent
impl PartialEq for ModuleHealthEvent
Sourcefn eq(&self, other: &ModuleHealthEvent) -> bool
fn eq(&self, other: &ModuleHealthEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ModuleHealthEvent
impl StructuralPartialEq for ModuleHealthEvent